Download Assessment Decisions
assessments(
assessment_unit_id = NULL,
state_code = NULL,
organization_id = NULL,
reporting_cycle = NULL,
use = NULL,
use_support = NULL,
parameter = NULL,
parameter_status_name = NULL,
probable_source = NULL,
agency_code = NULL,
ir_category = NULL,
state_ir_category_code = NULL,
multicategory_search = NULL,
last_change_later_than_date = NULL,
last_change_earlier_than_date = NULL,
return_count_only = FALSE,
exclude_assessments = FALSE,
tidy = TRUE,
.unnest = TRUE,
...
)If tidy = FALSE the raw JSON string is returned, else the JSON
data is parsed and returned as tibbles.
(character) Specify the specific assessment unit assessment data to return. Multiple values can be provided. optional
(character) Filters returned assessments to those from the specified state. optional
(character) Filters the returned assessments to those belonging to the specified organization. optional
(character) Filters the returned assessments to those for the specified reporting cycle. The reporting cycle refers to the four-digit year that the reporting cycle ended. Defaults to the current cycle. optional
(character) Filters the returned assessments to those with the specified uses. Multiple values can be provided. optional
(character) Filters returned assessments to those fully
supporting the specified uses or that are threatened. Multiple values can
be provided. Allowable values include "X"= Not Assessed, "I"=
Insufficient Information, "F"= Fully Supporting, "N"= Not
Supporting, and "T"= Threatened. optional
(character) Filters the returned assessments to those with one or more of the specified parameters. Multiple values can be provided. optional
(character) Filters the returned assessments to
those with one or more associated parameters meeting the provided value.
Valid values are "Meeting Criteria", "Cause", "Observed
Effect". Multiple valuse can be provided. optional
(character) Filters the returned assessments to those having the specified probable source. Multiple values can be provided. optional
(character) Filters the returned assessments to those by
the type of agency responsible for the assessment. Allowed values are
"E"=EPA, "S"=State, "T"=Tribal. optional
(character) Filters the returned assessments to those having the specified IR category. Multiple values can be provided. optional
(character) Filters the returned assessments to include those having the provided codes.
(character) Specifies whether to search at multiple levels. If this parameter is set to “Y” then the query applies the EPA IR Category at the Assessment, UseAttainment, and Parameter levels; if the parameter is set to “N” it looks only at the Assessment level.
(character) Filters the returned
assessments to only those last changed after the provided date. Must be a
character with format: "yyyy-mm-dd". optional
(character) Filters the returned
assessments to only those last changed before the provided date. Must be a
character with format: "yyyy-mm-dd". optional
(logical) If TRUE returns only the
documents associated with the Assessment cycle instead of the assessment
data. Defaults is FALSE.
(logical) TRUE (default) the function returns a tidied
tibble. FALSE the function returns the raw JSON string.
(logical) TRUE (default) the function attempts to unnest
data to longest format possible. This defaults to TRUE for backwards
compatibility but it is suggested to use FALSE.
list of curl options passed to crul::HttpClient()
One or more of the following arguments must be included:
action_id, assessment_unit_id, state_code or
organization_id. Multiple values are allowed for indicated arguments
and should be included as a comma separated values in the string (eg.
organization_id="TCEQMAIN,DCOEE").
if (FALSE) {
## Return all assessment decisions with specified parameters
assessments(organization_id = "SDDENR",
probable_source = "GRAZING IN RIPARIAN OR SHORELINE ZONES")
## Returns the raw JSONs instead:
assessments(organization_id = "SDDENR",
probable_source = "GRAZING IN RIPARIAN OR SHORELINE ZONES", tidy = FALSE)
}
Run the code above in your browser using DataLab